import React, { useState } from "react";
import { useNavigate } from "react-router-dom";
import MailIcon from "d:/360ExtremeBrowserDownload/Mail.svg";
import PasswordEyeIcon from "d:/360ExtremeBrowserDownload/Password eye.svg";
import FrameImage from "../assets/images/Frame201.svg";

import "../styles.css"; // Import the CSS file

const LoginPage = () => {
  const [showPassword, setShowPassword] = useState(false);
  const [email, setEmail] = useState("");
  const [emailError, setEmailError] = useState("");
  const navigate = useNavigate();

  const togglePasswordVisibility = () => {
    setShowPassword(!showPassword);
  };

  const validateEmail = (email) => {
    const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
    return emailRegex.test(email);
  };

  const handleCheckStatusClick = () => {
    if (!validateEmail(email)) {
      setEmailError("Please enter a valid email address.");
      return;
    }

    const allowedUrls = ["/status"];
    const targetUrl = "/status";

    if (allowedUrls.includes(targetUrl)) {
      navigate(targetUrl);
    } else {
      console.error("Invalid URL redirection attempt");
    }
  };

  return (
    <div className="flex items-center justify-center min-h-screen" style={{ background: '#E9FAFF' }}>
      <div className="absolute top-[66px] left-[139px]">
        <h1 className="font-montserrat font-bold text-[48.31px] leading-[100%]">
          OMPOI - Seller
        </h1>
      </div>

      <div className="absolute bg-white p-8 flex"
        style={{
          width: '1460.608px',
          height: '729px',
          top: '194px',
          left: '134px',
          borderRadius: '32.6px',
          boxShadow: '0px 3.91px 11.74px 0px #2E268414'
        }}>
        
        {/* Left Side - Illustration */}
        <div className="w-1/2 flex items-center justify-center p-5">
          <img src={FrameImage} alt="Illustration" className="w-full h-auto" />
        </div>

        {/* Divider */}
        <div className="absolute"
          style={{
            height: '624.67px',
            width: '1.3px',
            top: '52.16px',
            left: '730.3px',
            backgroundColor: '#E2E7EE',
            transform: 'rotate(0deg)'
          }}>
        </div>

        {/* Right Side - Login Form */}
        <div className="w-1/2 p-10 flex flex-col justify-center">
          <div style={{
            width: '231px',
            height: '41px',
            top: '105px',
            left: '996px',
            position: 'absolute',
            fontFamily: 'Montserrat',
            fontWeight: '600',
            fontSize: '33.91px',
            lineHeight: '100%',
            letterSpacing: '0px',
            color: '#101418'
          }}>
            Check Status
          </div>

          {/* Email Input */}
<div className="mb-4" style={{ width: '65%' }}> 
  <label className="block text-[#101418] text-[16px] font-medium mb-2">
    Email ID
  </label>
  <div className="relative">
    <input
      type="email"
      placeholder="Enter Email ID"
      value={email}
      onChange={(e) => setEmail(e.target.value)}
      className="w-full px-4 py-3 border border-[#E2E7EE] rounded-xl bg-transparent text-[#45505F] 
                 placeholder:text-[#A1A9B8] focus:outline-none focus:ring-2 focus:ring-blue-400"
    />
    <img
      src={MailIcon}
      alt="Mail Icon"
      className="absolute right-4 top-4 w-5 h-5"
    />
  </div>
  {emailError && <p className="text-red-500 text-sm mt-1">{emailError}</p>}
</div>

{/* Password Input */}
<div className="mb-4" style={{ width: '65%' }}> 
  <label className="block text-[#101418] text-[16px] font-medium mb-2">
    Password
  </label>
  <div className="relative">
    <input
      type={showPassword ? "text" : "password"}
      placeholder="Enter your password"
      className="w-full px-4 py-3 border border-[#E2E7EE] rounded-xl bg-transparent text-[#45505F] 
                 placeholder:text-[#A1A9B8] focus:outline-none focus:ring-2 focus:ring-blue-400"
    />
    <img
      src={PasswordEyeIcon}
      alt="Password Eye Icon"
      className="absolute right-4 top-4 w-5 h-5 cursor-pointer"
      onClick={togglePasswordVisibility}
    />
  </div>
</div>

{/* Forgot Password and Create Account Links */}
<div className="flex justify-between text-sm mb-6 w-[65%]">
  <a href="#" className="text-[#101418] font-semibold">Forgot Password?</a>
  <a href="#" className="text-[#FFBD69] font-semibold">Create an Account</a>
</div>


          {/* Check Status Button */}
          <div style={{
            width: '300.44px',
            height: '61.80px',
            top: '524.08px',
            left: '984.24px',
            position: 'absolute',
            borderRadius: '34.76px',
            display: 'flex',
            justifyContent: 'center',
            alignItems: 'center',
            paddingTop: '13.9px',
            paddingRight: '41.71px',
            paddingBottom: '13.9px',
            paddingLeft: '41.71px',
            gap: '13.9px'
          }}>
            <button
              onClick={handleCheckStatusClick}
              className="w-full bg-transparent text-[#030A1E] py-2 rounded-full hover:bg-orange-500 hover:text-white transition animated-button"
              style={{
                fontSize: '22.24px',
                fontFamily: 'Montserrat',
                fontWeight: '500',
                lineHeight: '33.37px',
                letterSpacing: '0.14px',
                textAlign: 'center',
                border: '2.13px solid #FFBD69'
              }}
            >
              <div style={{
                textAlign: 'center',
                color: '#030A1E',
                fontSize: '22.24px',
                fontFamily: 'Montserrat',
                fontWeight: '500',
                lineHeight: '33.37px',
                letterSpacing: '0.14px',
                wordWrap: 'break-word',
                width: '100%',
                height: '34px',
                background: 'transparent',
                borderRadius: '34.76px',
                display: 'flex',
                justifyContent: 'center',
                alignItems: 'center'
              }}>
                Check Status
              </div>
            </button>
          </div>
        </div>
      </div>
    </div>
  );
};

export default LoginPage;
